@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-close-confirmation-dialog.c,v 1.13 2005/12/12 17:27:56 pborelli Exp $
+ * $Id: gedit-close-confirmation-dialog.c,v 1.14 2006/03/14 10:53:12 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -315,7 +315,7 @@ get_selected_docs (GtkTreeModel *store)
 	return list;
 }
 
-const GList * 
+GList *
 gedit_close_confirmation_dialog_get_selected_documents (GeditCloseConfirmationDialog *dlg)
 {
 	GeditCloseConfirmationDialogPrivate *priv;
