@@ -26,7 +26,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-prefs-manager-app.c,v 1.11 2006/01/05 18:35:10 paolo Exp $
+ * $Id: gedit-prefs-manager-app.c,v 1.12 2006/01/19 18:16:00 paolo Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1110,8 +1110,9 @@ gedit_prefs_manager_auto_save_changed (GConfClient *client,
 		while (l != NULL)
 		{
 			GeditDocument *doc = GEDIT_DOCUMENT (l->data);
+			GeditTab *tab = gedit_tab_get_from_document (doc);
 
-			gedit_document_set_auto_save_enabled (doc, auto_save);
+			gedit_tab_set_auto_save_enabled (tab, auto_save);
 
 			l = l->next;
 		}
@@ -1138,8 +1139,9 @@ gedit_prefs_manager_auto_save_changed (GConfClient *client,
 		while (l != NULL)
 		{
 			GeditDocument *doc = GEDIT_DOCUMENT (l->data);
+			GeditTab *tab = gedit_tab_get_from_document (doc);
 
-			gedit_document_set_auto_save_interval (doc, auto_save_interval);
+			gedit_tab_set_auto_save_interval (tab, auto_save_interval);
 
 			l = l->next;
 		}
