@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-utils.c,v 1.71 2006/01/03 17:19:10 paolo Exp $
+ * $Id: gedit-utils.c,v 1.75 2006/02/12 16:51:32 paolo Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -280,7 +280,7 @@ gedit_utils_uri_exists (const gchar* text_uri)
 		
 	g_return_val_if_fail (text_uri != NULL, FALSE);
 	
-	gedit_debug_message (DEBUG_FILE, "text_uri: %s", text_uri);
+	gedit_debug_message (DEBUG_UTILS, "text_uri: %s", text_uri);
 
 	uri = gnome_vfs_uri_new (text_uri);
 	g_return_val_if_fail (uri != NULL, FALSE);
@@ -289,7 +289,7 @@ gedit_utils_uri_exists (const gchar* text_uri)
 
 	gnome_vfs_uri_unref (uri);
 
-	gedit_debug_message (DEBUG_FILE, res ? "TRUE" : "FALSE");
+	gedit_debug_message (DEBUG_UTILS, res ? "TRUE" : "FALSE");
 
 	return res;
 }
@@ -643,7 +643,8 @@ gedit_utils_make_valid_utf8 (const char *name)
 			string = g_string_sized_new (remaining_bytes);
 		}
 		g_string_append_len (string, remainder, valid_bytes);
-		g_string_append_c (string, '?');
+		/* append U+FFFD REPLACEMENT CHARACTER */
+		g_string_append (string, "\357\277\275");
 
 		remaining_bytes -= valid_bytes + 1;
 		remainder = invalid + 1;
@@ -654,7 +655,6 @@ gedit_utils_make_valid_utf8 (const char *name)
 	}
 
 	g_string_append (string, remainder);
-	g_string_append (string, " (invalid encoding)");
 	
 	g_assert (g_utf8_validate (string->str, -1, NULL));
 
@@ -879,10 +879,6 @@ gedit_utils_is_valid_uri (const gchar *uri)
 }
 
 
-
-#define GEDIT_MISSING_FILE    N_("<span size=\"large\" weight=\"bold\">Unable to find file <i>%s</i>.</span>\n\nPlease, check your installation.")
-#define GEDIT_MISSING_WIDGETS N_("<span size=\"large\" weight=\"bold\">Unable to find the required widgets inside file <i>%s</i>..</span>\n\nPlease, check your installation.")
-
 /**
  * gedit_utils_get_glade_widgets:
  * @filename: the path to the glade file
@@ -910,6 +906,8 @@ gedit_utils_get_glade_widgets (const gchar *filename,
 	va_list args;
 	const gchar *name;
 	gchar *msg;
+	gchar *filename_markup;
+	gchar *msg_plain;
 	gboolean ret = TRUE;
 
 	g_return_val_if_fail (filename != NULL, FALSE);
@@ -921,11 +919,18 @@ gedit_utils_get_glade_widgets (const gchar *filename,
 	gui = glade_xml_new (filename, root_node, NULL);
 	if (!gui)
 	{
-		msg = g_strdup_printf (GEDIT_MISSING_FILE, filename);
+		filename_markup = g_markup_printf_escaped ("<i>%s</i>", filename);
+		msg_plain = g_strdup_printf (_("Unable to find file %s."),
+				filename_markup);
+		msg = g_strconcat ("<span size=\"large\" weight=\"bold\">",
+				msg_plain, "</span>\n\n",
+				_("Please check your installation."), NULL);
 		label = gtk_label_new (msg);
 
 		gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
+		g_free (filename_markup);
+		g_free (msg_plain);
 		g_free (msg);
 
 		*error_widget = label;
@@ -942,11 +947,19 @@ gedit_utils_get_glade_widgets (const gchar *filename,
 		*wid = glade_xml_get_widget (gui, name);
 		if (*wid == NULL)
 		{
-			msg = g_strdup_printf (GEDIT_MISSING_WIDGETS, filename);
+			filename_markup = g_markup_printf_escaped ("<i>%s</i>", filename);
+			msg_plain = g_strdup_printf (
+					_("Unable to find the required widgets inside file %s."),
+					filename_markup);
+			msg = g_strconcat ("<span size=\"large\" weight=\"bold\">",
+					msg_plain, "</span>\n\n",
+					_("Please check your installation."), NULL);
 			label = gtk_label_new (msg);
 
 			gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
+			g_free (filename_markup);
+			g_free (msg_plain);
 			g_free (msg);
 
 			*error_widget = label;
